CanvasApi class abstract

画布打印接口 构建画布内容按画布区域打印(标签、黑标、针式类型打印机) SdkException返回API调用异常如不支持此接口 RenderError回调API执行期间的异常如打印机无法处理

Implementers

Constructors

CanvasApi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

initCanvas(LabelStyle style) → Future<void>
初始化画布. 指定打印标签的画布大小、基础格式
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printCanvas(int count, PrintResult listener) → Future<void>
开始打印画布内容
renderArea(AreaStyle format) → Future<void>
在画布上绘制图形.
renderBarCode(String code, BarcodeStyle style) → Future<void>
在画布上绘制条形码.
renderBitmap(Uint8List bitmap, BitmapStyle style) → Future<void>
在画布上绘制位图.
renderQrCode(String text, QrStyle style) → Future<void>
在画布上绘制二维码.
renderText(String text, TextStyle style) → Future<void>
在画布上绘制文本内容.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited