CanvasApiImpl class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

initCanvas(LabelStyle style) → Future<void>
初始化画布. 指定打印标签的画布大小、基础格式
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printCanvas(int count, PrintResult listener) → Future<void>
开始打印画布内容
override
renderArea(AreaStyle format) → Future<void>
在画布上绘制图形.
override
renderBarCode(String code, BarcodeStyle style) → Future<void>
在画布上绘制条形码.
override
renderBitmap(Uint8List bitmap, BitmapStyle style) → Future<void>
在画布上绘制位图.
override
renderQrCode(String text, QrStyle style) → Future<void>
在画布上绘制二维码.
override
renderText(String text, TextStyle style) → Future<void>
在画布上绘制文本内容.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → CanvasApiImpl
no setter