LineApiImpl class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addText(String text, TextStyle style) → Future<void>
在当前行追加方式渲染文本内容
override
autoOut() → Future<void>
自动出纸
override
enableTransMode(bool enable) → Future<void>
开启或关闭事务模式
override
initLine(BaseStyle format) → Future<void>
初始化行样式
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBarCode(String code, BarcodeStyle style) → Future<void>
在当前行渲染条码
override
printBitmap(Uint8List bitmap, BitmapStyle style) → Future<void>
在当前行渲染位图
override
printDividingLine(DividingLine style, int offset) → Future<void>
在当前行渲染分割线
override
printQrCode(String code, QrStyle style) → Future<void>
在当前行渲染二维码
override
printText(String text, TextStyle style) → Future<void>
在当前行渲染文本内容
override
printTexts(List<String> text, List<int> colsWidthArr, List<TextStyle> styles) → Future<void>
在当前行渲染多列文本内容
override
printTrans(PrintResult listener) → Future<void>
在事务模式下触发打印
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → LineApiImpl
no setter