LineApi class abstract

行渲染接口 构建普通的热敏小票样张使用行渲染接口(热敏打印机类型) SdkException返回API调用异常如不支持此接口 RenderError回调API执行期间的异常如打印机无法处理

Implementers

Constructors

LineApi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addText(String text, TextStyle style) → Future<void>
在当前行追加方式渲染文本内容
autoOut() → Future<void>
自动出纸
enableTransMode(bool enable) → Future<void>
开启或关闭事务模式
initLine(BaseStyle format) → Future<void>
初始化行样式
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBarCode(String code, BarcodeStyle style) → Future<void>
在当前行渲染条码
printBitmap(Uint8List bitmap, BitmapStyle style) → Future<void>
在当前行渲染位图
printDividingLine(DividingLine style, int offset) → Future<void>
在当前行渲染分割线
printQrCode(String code, QrStyle style) → Future<void>
在当前行渲染二维码
printText(String text, TextStyle style) → Future<void>
在当前行渲染文本内容
printTexts(List<String> text, List<int> colsWidthArr, List<TextStyle> styles) → Future<void>
在当前行渲染多列文本内容
printTrans(PrintResult listener) → Future<void>
在事务模式下触发打印
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited