Printer class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Printer({String? printerId})
const
Printer.fromJson(Map<String, dynamic> json)
factory

Properties

canvasApi → CanvasApi
标签打印
no setter
cashDrawerApi → CashDrawerApi
钱箱控制
no setter
commandApi → CommandApi
指令集
no setter
hashCode → int
The hash code for this object.
no setterinherited
lineApi → LineApi
热敏小票
no setter
printerId → String?
final
queryApi → QueryApi
查询相关
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited