PrinterInfo enum

打印机信息枚举类

Inheritance
Available extensions

Values

ID → const PrinterInfo
NAME → const PrinterInfo
VERSION → const PrinterInfo
DISTANCE → const PrinterInfo
CUTTER → const PrinterInfo
HOT → const PrinterInfo
DENSITY → const PrinterInfo
TYPE → const PrinterInfo
PAPER → const PrinterInfo
GRAY → const PrinterInfo
NULL → const PrinterInfo

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

findInfo(String info) → PrinterInfo

Constants

values → const List<PrinterInfo>
A constant List of the values in this enum, in order of their declaration.