Symbology enum

Inheritance
Available extensions

Values

UPCA → const Symbology
const Symbology(0, "UPCA")
UPCE → const Symbology
const Symbology(1, "UPCE")
EAN13 → const Symbology
const Symbology(2, "EAN13")
EAN8 → const Symbology
const Symbology(3, "EAN8")
CODE39 → const Symbology
const Symbology(4, "39")
ITF → const Symbology
const Symbology(5, "25")
CODABAR → const Symbology
const Symbology(6, "CODA")
CODE93 → const Symbology
const Symbology(7, "93")
CODE128 → const Symbology
const Symbology(8, "128M")
EAN128 → const Symbology
const Symbology(9, "EAN128")
CODE128A → const Symbology
const Symbology(10, "128")
ITF_C → const Symbology
const Symbology(11, "25C")
CODE39_S → const Symbology
const Symbology(12, "39S")
CODE39_C → const Symbology
const Symbology(13, "39C")
EAN13_2 → const Symbology
const Symbology(14, "EAN13+2")
UPCA_2 → const Symbology
const Symbology(15, "UPCA+2")
UPCA_5 → const Symbology
const Symbology(16, "UPCA+5")
EAN13_5 → const Symbology
const Symbology(17, "EAN13+5")
EAN8_2 → const Symbology
const Symbology(18, "EAN8+2")
EAN8_5 → const Symbology
const Symbology(19, "EAN8+5")
UPCE_2 → const Symbology
const Symbology(20, "UPCE+2")
UPCE_5 → const Symbology
const Symbology(21, "UPCE+5")

Properties

code → int
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Symbology>
A constant List of the values in this enum, in order of their declaration.