AreaFormat class

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AreaFormat({int style = 0, int endX = 0, int endY = 0, int thickness = 0})
AreaFormat.fromJson(Map<String, dynamic> json)
factory

Properties

align ↔ int
对齐方式
getter/setter pairinherited
endX ↔ int
结束坐标位置X
getter/setter pair
endY ↔ int
结束坐标位置Y
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
预打印内容的高度
getter/setter pairinherited
renderColor ↔ int
指定渲染的颜色
getter/setter pairinherited
rotate ↔ int
旋转角度
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ int
区域样式
getter/setter pair
thickness ↔ int
线条粗细大小
getter/setter pair
width ↔ int
预打印内容的宽度
getter/setter pairinherited
xOffset ↔ int
在行打印中对应相对当前横向位置 在图打印中对应 x 轴坐标位置
getter/setter pairinherited
yOffset ↔ int
在行打印中对应相对上一行的位置 在图打印中对应 y 轴坐标位置
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited