MyPluginPlatformInterface class abstract

Inheritance
  • Object
  • PlatformInterface
  • MyPluginPlatformInterface
Implementers

Constructors

MyPluginPlatformInterface({required Object token})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addText(String text, TextStyle style) → Future<void>
在当前行追加方式渲染文本内容
autoOut() → Future<void>
自动出纸
destroy() → Future<void>
enableTransMode(bool enable) → Future<void>
开启或关闭事务模式
getInfo(PrinterInfo info) → Future<String?>
getMyFirstChannelTest() → Future<String?>
getPrinter(PrinterListener listener) → Future<void>
getStatus() → Future<int?>
initCanvas(LabelStyle style) → Future<void>
初始化画布. 指定打印标签的画布大小、基础格式
initLine(BaseStyle format) → Future<void>
初始化行样式
isOpen() → Future<bool?>
返回本地钱箱的开启状态 @return true 钱箱开启 false 钱箱未开启 @throws SdkException 接口实现情况,除商米打印机外目前接口返回不支持
log(bool enable, String? tag) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() → Future<Map<String, dynamic>>
打开本地钱箱 @param resultListener 钱箱开启情况,接口可执行后具体到调用打印机时的异常 @throws SdkException 接口实现情况,除商米打印机外目前接口返回不支持异常
printBarCode(String code, BarcodeStyle style) → Future<void>
在当前行渲染条码
printBitmap(Uint8List bitmap, BitmapStyle style) → Future<void>
在当前行渲染位图
printCanvas(int count) → Future<Map<String, dynamic>>
开始打印画布内容
printDividingLine(DividingLine style, int offset) → Future<void>
在当前行渲染分割线
printQrCode(String code, QrStyle style) → Future<void>
在当前行渲染二维码
printText(String text, TextStyle style) → Future<void>
在当前行渲染文本内容
printTexts(List<String> text, List<int> colsWidthArr, List<TextStyle> styles) → Future<void>
在当前行渲染多列文本内容
printTextTest() → Future<void>
printTrans() → Future<Map<String, dynamic>>
在事务模式下触发打印
renderArea(AreaStyle format) → Future<void>
在画布上绘制图形.
renderBarCode(String code, BarcodeStyle style) → Future<void>
在画布上绘制条形码.
renderBitmap(Uint8List bitmap, BitmapStyle style) → Future<void>
在画布上绘制位图.
renderQrCode(String text, QrStyle style) → Future<void>
在画布上绘制二维码.
renderText(String text, TextStyle style) → Future<void>
在画布上绘制文本内容.
sendEscCommand(Uint8List esc) → Future<void>
sendTsplCommand(Uint8List tspl) → Future<void>
startSettings(SettingItem item) → Future<bool?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited