PrinterSdk class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → Future<void>
3.释放SDK
getMyFirstChannelTest() → Future<String?>
getPrinter(PrinterListener listener) → Future<void>
1.获取打印机
log(bool enable, String? tag) → Future<void>
2.设置接口日志输出
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printTextTest() → Future<void>
startSettings(SettingItem item) → Future<bool?>
4.跳转打印机配置
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → PrinterSdk
no setter