BarcodeStyle class

条形码样式属性

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BarcodeStyle(BarcodeFormat barcodeFormat)
JsonSerializable不能使用私有构造
BarcodeStyle.fromJson(Map<String, dynamic> json)
factory

Properties

barcodeFormat → BarcodeFormat
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() → BarcodeFormat
返回当前的条形码格式
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAlign(Align align) → BarcodeStyle
指定条码相对坐标的对齐位置
setBarHeight(int height) → BarcodeStyle
条形码码高度
setDotWidth(int width) → BarcodeStyle
条形码码块宽度
setHeight(int height) → BarcodeStyle
自定义高度
setPosX(int offset) → BarcodeStyle
设置条码内容的 x 坐标
setPosY(int offset) → BarcodeStyle
设置条码内容的 y 坐标
setReadable(HumanReadable readable) → BarcodeStyle
人类可识读位置
setRotate(Rotate rotate) → BarcodeStyle
指定条码旋转方向
setSymbology(Symbology symbology) → BarcodeStyle
条码类型
setWidth(int width) → BarcodeStyle
自定义宽度
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getStyle() → BarcodeStyle
返回当前设置的样式属性对象